Learn R Programming

sss (version 0.0-10)

sss-package: Tools for importing files in the triple-s .(Standard Survey Structure) format.

Description

sss is a set of tools to import survey files in the .sss (triple-s) format. triple-s is a standard to transfer survey data between applications.

Arguments

References

http://www.triple-s.org/ The most important exported function is: read.sss