Learn R Programming

sss (version 0.0-10)

read.sss: Reads a triple-s XML (asc) data file, as specified by the triple-s XML standard.

Description

This function reads and parses a .sss XML metadata file as well as its associated .asc data file. The .sss standard defines a standard survey structure

Usage

read.sss(sssFilename, ascFilename, sep = "_")

Arguments

sssFilename
Character string: name of .sss file containing the survey metadata
ascFilename
Character string: name of .asc file containing survey data
sep
Character vector defining the string that separates question and subquestion labels, e.g. c("Q_1", "Q_2")

Value

  • A data frame with one element (column) for each variable in the data set. The data.frame contains several attributes: [object Object]

References

http://www.triple-s.org/

Examples

Run this code
# Not executed
# read.sss("sample.sss, sample.asc")

Run the code above in your browser using DataLab